Discover Packages
github.com/Webbaum/w0q
models
package
Version:
v0.0.0-...-1158c2d
Opens a new window with list of versions in this module.
Published: Jul 15, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Url struct {
ID string `json:"id" gorm:"primary_key"`
Url string `json:"url"`
Date time .Time `json:"date" gorm:"type:datetime"`
IP string `json:"-"`
}
type UrlInput struct {
Url string `json:"url" binding:"required"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.